@@ -10,6 +10,7 @@ commands = {"cd <file>": "move current directory.",
 "pwd": "print now directory.",
 "ls" : "list directory.",
 "upload <file>": "upload file.",
+"download <file>": "download file",
 "rm<file>": "delete file.",
 "mkdir <dir>": "make directory.",
 "rmdir <dir>": "delete directory.",
@@ -40,14 +41,16 @@ def term():
 			if os.access(file, os.F_OK): f = open(file,"r")
 			else: print "'%s' is not found." % file;continue;
 		
-			conn.storbinary("STOR %s" % file,f)
+			try: conn.storbinary("STOR %s" % file,f)
+			except: print "Error! '%s' file may not exist." % file
 		
 		elif cmd.split(" ")[0] == "download":
 			try: file = cmd.split(" ")[1]
 			except: print "argument is not found.";continue;
 			
 			f = open(file,"w")
-			conn.retrbinary("RETR %s"%file,f.write)
+			try: conn.retrbinary("RETR %s"%file,f.write)
+			except: print "Error! '%s' file may not exist." % file;continue;
 			print "Completed."
 		
 		elif cmd.split(" ")[0] == "cd":
@@ -61,7 +64,8 @@ def term():
 			try: file = cmd.split(" ")[1]
 			except: print "argument is not found.";continue;
 			
-			conn.delete(file)
+			try: conn.delete(file)
+			except: print "Error! '%s' file may not exist or directory." % file;continue;
 		
 		elif cmd.split(" ")[0] == "mkdir":
 			try: dir = cmd.split(" ")[1]
@@ -73,8 +77,9 @@ def term():
 			try: dir = cmd.split(" ")[1]
 			except: print "argument is not found.";continue;
 		
-			conn.rmd(dir)
-	
+			try: conn.rmd(dir)
+			except: print "Error! '%s' dir is not empty." % dir
+			
 		elif cmd == "pwd":
 			print conn.pwd()
 		
@@ -82,7 +87,8 @@ def term():
 			try: fromname = cmd.split(" ")[1];toname = cmd.split(" ")[2]
 			except: print "argument is not found.";continue;
 		
-			conn.rename(fromname,toname)
+			try: conn.rename(fromname,toname)
+			except: print "Error! '%s' file may not exist." % fromname
 		
 		elif cmd == "help":
 			for key,value in commands.iteritems():
